@@ -11,6 +11,10 @@ Lingua::EN::ABC - American, British, and Canadian English
 
 =head1 DESCRIPTION
 
+This is an experimental module. This module offers functions to
+convert between the spellings and vocabulary of American, British, and
+Canadian versions of English. The interface is described below.
+
 =head1 FUNCTIONS
 
 =head2 a2b
@@ -21,7 +25,7 @@ Lingua::EN::ABC - American, British, and Canadian English
 An option C<oxford> controls whether to use Oxford spelling (realize
 rather than realise):
 
-    my $oxford_british = c2b ($canadian, oxford => 1);
+    my $oxford_british = a2b ('realize', oxford => 1);
 
 =head2 b2a
 
@@ -60,6 +64,16 @@ whether to use Oxford spelling (realize rather than realise):
 
     my $oxford_british = c2b ($canadian, oxford => 1);
 
+=head1 SEE ALSO
+
+This module's design is up for discussion. You can either use the
+Github issues page at
+L<https://github.com/benkasminbullock/Lingua-EN-ABC/issues> or the
+Prepan site at L<http://prepan.org/module/nXWEF3to2nu>.
+
+The file containing the spelling variations is "abc.txt" in the top
+directory of the distribution.
+
 =head1 AUTHOR
 
 Ben Bullock, <bkb@cpan.org>
@@ -83,7 +97,7 @@ use strict;
 use Carp;
 use JSON::Parse 'json_file_to_perl';
 
-our $VERSION = 0.01;
+our $VERSION = 0.02;
 
 # Load the data from the file.
 
